# SAP LeanIX App for Microsoft Teams
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#overview)
  * [Configuring Microsoft Teams Integration](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#configuring-microsoft-teams-integration)
  * [Adding the SAP LeanIX App in Microsoft Teams](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#adding-the-sap-leanix-app-in-microsoft-teams)
  * [Activating Notifications](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#activating-notifications)
  * [Getting Fact Sheet Information](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#getting-fact-sheet-information)
  * [Managing Notifications](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#managing-notifications)
  * [Overview of Microsoft Teams Users](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams#overview-of-microsoft-teams-users)


Setting up the SAP LeanIX App for Microsoft Teams
